@@ -51,7 +51,7 @@ void DVIInit(struct dvi_data* dvi)
   }
   dvi->conv = (1.0/(((double)dvi->num / (double)dvi->den) *
 		    ((double)dvi->mag / 1000.0) *
-		    ((double)resolution/254000.0)))+0.5;
+		    ((double)dpi*shrinkfactor/254000.0)))+0.5;
   DEBUG_PRINT(DEBUG_DVI,(" (%d)",dvi->conv));
   k = UNumRead(pre+14,1);
   DEBUG_PRINT(DEBUG_DVI,(" '%.*s'",k,pre+15));
@@ -89,7 +89,7 @@ struct dvi_data* DVIOpen(char* dviname,char* outname)
       *tmpstring = '\0';
     strcat(dvi->outname, "%d.png");
   } else {
-    dvi->outname = malloc(strlen(outname));
+    dvi->outname = malloc(strlen(outname)+1);
     if (dvi->outname==NULL)
       Fatal("cannot allocate space for output filename");
     strcpy(dvi->outname,outname);
