@@ -156,9 +156,8 @@ struct encoding {
 #define FONT_TYPE_PK            1
 struct pk_char {                   /* PK character */
   dviunits       tfmw;             /* TFM width                         */
-  unsigned char  greys;            /* ink is black at this value        */
   pixels         w,h;              /* width height in pixels            */
-  char          *data;             /* glyph data                        */
+  unsigned char *data;             /* glyph data (0=transp, 255=max ink)*/
   pixels         xOffset, yOffset; /* x offset and y offset in pixels   */
   unsigned char *mmap;             /* Points to beginning of PK data    */
   uint32_t       length;           /* Length of PK data                 */
@@ -189,7 +188,7 @@ struct font_entry {    /* font entry */
   uint32_t     c, s, d;                                                
   uint8_t      a, l;                                                   
   char         n[STRSIZE];      /* FNT_DEF command parameters        */
-  uint32_t     font_mag;        /* computed from s and d             */
+  int          dpi;             /* computed from s and d             */
   char         name[STRSIZE];   /* full name of PK/VF file           */
   int          filedes;         /* file descriptor                   */
   unsigned char* mmap,*end;     /* memory map                        */
@@ -382,8 +381,10 @@ EXTERN struct timeb timebuffer;
 # endif
 #endif /* TIMING */
 
-EXTERN int   resolution INIT(300);
-EXTERN char *MFMODE     INIT("cx");
+EXTERN char*  user_mfmode          INIT(NULL);
+EXTERN int    user_bdpi            INIT(0);
+EXTERN int    dpi                  INIT(100);
+
 #ifdef HAVE_GDIMAGEPNGEX
 EXTERN int   compression INIT(1);
 #endif
