@@ -70,7 +70,7 @@ bool DecodeArgs(int argc, char ** argv)
 	    debug = DEBUG_DEFAULT;
 	  Message(PARSE_STDIN,"Debug output enabled\n");
 #ifdef HAVE_LIBKPATHSEA
-	  kpathsea_debug = debug / LASTDEBUG;
+	  kpathsea_debug = debug / LASTDEBUG / 2 ;
 #endif
 #else
 	  Warning("This instance of %s was compiled without the debug (-d) option",
@@ -101,8 +101,8 @@ bool DecodeArgs(int argc, char ** argv)
       case 'm':
 	if (strcmp(p,"ode") == 0 ) {
 	  if (argv[i+1])
-	    MFMODE = argv[++i] ;
-	  Message(PARSE_STDIN,"MetaFont mode: %s\n",MFMODE);
+	    user_mfmode = argv[++i] ;
+	  Message(PARSE_STDIN,"MetaFont mode: %s\n",user_mfmode);
 	  break;
 	}
 	goto DEFAULT;
@@ -213,6 +213,15 @@ bool DecodeArgs(int argc, char ** argv)
 	    Message(PARSE_STDIN,"Transp. background (fallback rgb %d,%d,%d)\n",
 		    bRed,bGreen,bBlue);
 	  break;
+	} else if (strcmp(p, "dpi")==0) {
+	  p+=3;
+	  if (*p == 0 && argv[i+1])
+	    p = argv[++i] ;
+	  user_bdpi = atoi(p);
+	  if (user_bdpi < 10 || user_bdpi > 10000)
+	    Fatal("bad --bdpi parameter (-D).") ;
+	  Message(PARSE_STDIN,"Bdpi: %d\n",user_bdpi);
+	  break;
 	} else if ( *p == 'd' ) { /* -bd border width */
 	  p++;
 	  if (*p == 0 && argv[i+1])
@@ -320,7 +329,7 @@ bool DecodeArgs(int argc, char ** argv)
 #ifdef HAVE_LIBKPATHSEA
 	  puts (KPSEVERSION);
 #endif
-	  puts ("Copyright (C) 2002-2003 Jan-ke Larsson.\n\
+	  puts ("Copyright (C) 2002-2004 Jan-ke Larsson.\n\
 There is NO warranty.  You may redistribute this software\n\
 under the terms of the GNU General Public License.\n\
 For more information about these matters, see the files\n\
@@ -335,10 +344,10 @@ named COPYING and dvipng.c.");
       case 'D' :
 	if (*p == 0 && argv[i+1])
 	  p = argv[++i] ;
-	resolution = atoi(p);
-	if (resolution < 10 || resolution > 10000)
-	  Fatal("bad dpi parameter (-D).") ;
-	Message(PARSE_STDIN,"Dpi: %d\n",resolution);
+	dpi = atoi(p);
+	if (dpi < 10 || dpi > 10000)
+	  Fatal("bad -D parameter.") ;
+	Message(PARSE_STDIN,"Dpi: %d\n",dpi);
 	break;
       case 'Q':       /* quality (= shrinkfactor) */
 	if (*p == 0 && argv[i+1])
@@ -365,7 +374,7 @@ named COPYING and dvipng.c.");
   }
 
   if (programname)
-    Message(BE_NONQUIET,"This is %s Copyright 2002-2003 Jan-ke Larsson\n",
+    Message(BE_NONQUIET,"This is %s Copyright 2002-2004 Jan-ke Larsson\n",
 	    PACKAGE_STRING);
 
   if (dviname != NULL) {
@@ -380,7 +389,7 @@ named COPYING and dvipng.c.");
 #ifdef DEBUG
     fprintf(stdout,"  -d #         Debug (# is the debug bitmap, 1 if not given)\n");
 #endif
-    fprintf(stdout,"  -D #         Resolution\n");
+    fprintf(stdout,"  -D #         Output resolution\n");
     fprintf(stdout,"  -M*          Don't make fonts\n");
     fprintf(stdout,"  -l #         Last page to be output\n");
     fprintf(stdout,"  -mode s      MetaFont mode (default cx)\n");
@@ -511,8 +520,6 @@ void Fatal (char *fmt, ...)
   exit(EXIT_FAILURE);
 }
 
-
-
 /*-->Warning*/
 /**********************************************************************/
 /*****************************  Warning  ******************************/
